<div class="jskomConfInput">
  <div ng-hide="matches" class="row collapse jskomConfInputLookup">
    <div class="ten mobile-three columns">
      <input type="text" spellcheck="false" autocorrect="off" autocapitalize="off"
             ng-disabled="conf" ng-model="lookup" />
    </div>
    <div class="two mobile-one columns">
      <button type="button" class="secondary button expand postfix" tabindex="-1"
         ng-disabled="isLoading || lookup.length < 1 || matches.length > 0"
         ng-readonly="isLoading" ng-click="getConf()">
        <i class="icon-search" ng-hide="isLoading"></i>
        <i class="icon-spinner icon-spin" ng-show="isLoading"></i>
      </button>
    </div>
  </div>
  
  <div ng-show="matches.length == 1" class="row collapse jskomConfInputConfName">
    <div class="ten mobile-three columns">
      <input type="text" class="" tabindex="-1" readonly autocorrect="off" autocapitalize="off"
             ng-disabled="!conf"
             ng-model="conf.name" />
    </div>
    <div class="two mobile-one columns">
      <button type="button" class="alert button expand postfix"
              ng-click="clearMatching()">
        <i class="icon-remove"></i>
      </button>
    </div>
  </div>
  
  <div ng-show="matches.length > 1" class="row collapse jskomConfInputMatches">
    <div class="ten mobile-three columns">
      <select class=""
              ng-model="model"
              ng-disabled="!conf"
              ng-options="mp.conf_no as mp.name for mp in matches">
      </select>
    </div>
    <div class="two mobile-one columns">
      <button type="button" class="alert button expand postfix"
              ng-click="clearMatching()">
        <i class="icon-remove"></i>
      </button>
    </div>
  </div>
</div>
