.jskomNoWrap {
    white-space: nowrap;
    overflow: hidden;
    display: block;
}

.jskomAlignRight {
    text-align: right !important;
}

.jskomTextForm textarea {
    resize: vertical;
    min-height: 100px;
}
