<div ng-controller="LoginTabsCtrl">
  <dl class="tabs">
    <dd ng-class="isTabActive('login')">
      <a ng-click="selectTab('login')">Log in</a>
    </dd>
    <dd ng-class="isTabActive('create')">
      <a ng-click="selectTab('create')">Create person</a>
    </dd>
  </dl>
  
  <ul class="tabs-content">
    <li ng-class="isTabActive('login')">
      <ng-include src="'login.html'|jskomTemplate"></ng-include>
    </li>
    
    <li ng-class="isTabActive('create')">
      <ng-include src="'newperson.html'|jskomTemplate"></ng-include>
    </li>
  </ul>
</div>
