/* font-face */
@font-face {
  font-family: "GeneralFoundicons";
  src: url("../../../fonts/foundicons/general/general_foundicons.eot");
  src: url("../../../fonts/foundicons/general/general_foundicons.eot?#iefix") format("embedded-opentype"), url("../../../fonts/foundicons/general/general_foundicons.woff") format("woff"), url("../../../fonts/foundicons/general/general_foundicons.ttf") format("truetype"), url("../../../fonts/foundicons/general/general_foundicons.svg#GeneralFoundicons") format("svg");
  font-weight: normal;
  font-style: normal;
}

/* global foundicon styles */
/* line 7, ../../../../../foundation/scss/foundicons/general/general_foundicons.scss */
[class*="foundicon-general-"] {
  display: inline;
  width: auto;
  height: auto;
  line-height: inherit;
  vertical-align: baseline;
  background-image: none;
  background-position: 0 0;
  background-repeat: repeat;
}

/* line 17, ../../../../../foundation/scss/foundicons/general/general_foundicons.scss */
[class*="foundicon-general-"]:before {
  font-family: "GeneralFoundicons";
  font-weight: normal;
  font-style: normal;
  text-decoration: inherit;
}

/* icons */
/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-settings:before {
  content: "\f000";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-heart:before {
  content: "\f001";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-star:before {
  content: "\f002";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-plus:before {
  content: "\f003";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-minus:before {
  content: "\f004";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-checkmark:before {
  content: "\f005";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-remove:before {
  content: "\f006";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-mail:before {
  content: "\f007";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-calendar:before {
  content: "\f008";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-page:before {
  content: "\f009";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-tools:before {
  content: "\f00a";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-globe:before {
  content: "\f00b";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-home:before {
  content: "\f00c";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-quote:before {
  content: "\f00d";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-people:before {
  content: "\f00e";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-monitor:before {
  content: "\f00f";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-laptop:before {
  content: "\f010";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-phone:before {
  content: "\f011";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-cloud:before {
  content: "\f012";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-error:before {
  content: "\f013";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-right-arrow:before {
  content: "\f014";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-left-arrow:before {
  content: "\f015";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-up-arrow:before {
  content: "\f016";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-down-arrow:before {
  content: "\f017";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-trash:before {
  content: "\f018";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-add-doc:before {
  content: "\f019";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-edit:before {
  content: "\f01a";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-lock:before {
  content: "\f01b";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-unlock:before {
  content: "\f01c";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-refresh:before {
  content: "\f01d";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-paper-clip:before {
  content: "\f01e";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-video:before {
  content: "\f01f";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-photo:before {
  content: "\f020";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-graph:before {
  content: "\f021";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-idea:before {
  content: "\f022";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-mic:before {
  content: "\f023";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-cart:before {
  content: "\f024";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-address-book:before {
  content: "\f025";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-compass:before {
  content: "\f026";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-flag:before {
  content: "\f027";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-location:before {
  content: "\f028";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-clock:before {
  content: "\f029";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-folder:before {
  content: "\f02a";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-inbox:before {
  content: "\f02b";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-website:before {
  content: "\f02c";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-smiley:before {
  content: "\f02d";
}

/* line 6, ../../../../../foundation/scss/foundicons/general/_settings.scss */
.foundicon-general-search:before {
  content: "\f02e";
}
